//---------------------------------------------------------------------------
#ifndef VCustomDBGridFilterDialogH 
#define VCustomDBGridFilterDialogH
//---------------------------------------------------------------------------
#include <SysUtils.hpp>
#include <Controls.hpp>
#include <Classes.hpp>
#include <Forms.hpp>

#include <dbgrids.hpp>
#include "VDBSortGrid.h"

class TVCustomDBGridFilterDialog;


//---------------------------------------------------------------------------
class PACKAGE TVCustomDBGridFilterField : public TCollectionItem
 {
  private     :
  AnsiString                 FCaption;
  AnsiString                 FFieldName;
  AnsiString                 FStartValue;
  AnsiString                 FEndValue;
  Word                       FMaxSize;
  bool                       FPeriod;

  void        __fastcall     SetCaption               (AnsiString    value);
  AnsiString  __fastcall     GetCaption               (void);

  void        __fastcall     SetFieldName             (AnsiString    value);
  AnsiString  __fastcall     GetFieldName             (void);

  void        __fastcall     SetStartValue            (AnsiString    value);
  AnsiString  __fastcall     GetStartValue            (void);

  void        __fastcall     SetEndValue              (AnsiString    value);
  AnsiString  __fastcall     GetEndValue              (void);

  void        __fastcall     SetMaxSize               (Word          value);
  Word        __fastcall     GetMaxSize               (void);

  void        __fastcall     SetPeriod                (bool          value);
  bool        __fastcall     GetPeriod                (void);

  protected   :
  virtual
  AnsiString  __fastcall     GetDisplayName();

  public      :
  __fastcall  virtual        TVCustomDBGridFilterField  (Classes::TCollection* Collection);
  __fastcall  virtual       ~TVCustomDBGridFilterField  (void);

  __published :
  __property AnsiString      Caption    = {read=GetCaption   , write=SetCaption};
  __property AnsiString      FieldName  = {read=GetFieldName , write=SetFieldName};
  __property AnsiString      StartValue = {read=GetStartValue, write=SetStartValue};
  __property AnsiString      EndValue   = {read=GetEndValue  , write=SetEndValue};
  __property Word            MaxSize    = {read=GetMaxSize   , write=SetMaxSize};
  __property bool            Period     = {read=GetPeriod    , write=SetPeriod};
 };
//---------------------------------------------------------------------------
class PACKAGE TVCustomDBGridFilterFields : public TCollection
 {
  private     :
  TVCustomDBGridFilterDialog   *FilterDialog;

  TVCustomDBGridFilterField*    GetField                 (int                        Index);
  void                    SetField                 (int                        Index,
                                                    TVCustomDBGridFilterField *Field);
  protected   :
  DYNAMIC Classes::TPersistent* __fastcall GetOwner   (void);

  public      :
  __fastcall                 TVCustomDBGridFilterFields  (TVCustomDBGridFilterDialog *FilterDialog,
                                                          System::TMetaClass         *FieldClass);

  __fastcall virtual        ~TVCustomDBGridFilterFields (void);

  __property TVCustomDBGridFilterField* Items[int Index] = {read=GetField, write=SetField};
 };
//---------------------------------------------------------------------------
class PACKAGE TVCustomDBGridFilterDialog : public TComponent
 {
  private     :
  TVDBSortGrid              *FGrid;
  TVCustomDBGridFilterFields   *FFields;
  bool                       FAutoFilter;
  AnsiString                 FFilter;
  TList                     *StartEditorListPtr;
  TList                     *EndEditorListPtr;
  TList                     *CheckBoxListPtr;
  TForm                     *FilterFormPtr;
  Word                       FWidth;
  Word                       FHeight;
  Word                       FMaxWidth;
  Word                       FMaxHeight;
  Word                       FSpaceY;
  Word                       FBorderWidth;
  Word                       FBorderHeight;
  AnsiString                 FCaption;
  bool                       FActive;

  void          __fastcall   SetGrid                  (TVDBSortGrid      *value);
  TVDBSortGrid* __fastcall   GetGrid                  (void);

  void        __fastcall     SetFields                (TVCustomDBGridFilterFields *value);
  TVCustomDBGridFilterFields*
              __fastcall     GetFields                (void);

  void        __fastcall     SetAutoFilter            (bool          Value);
  bool        __fastcall     GetAutoFilter            (void);

  void        __fastcall     SetWidth                 (Word          value);
  Word        __fastcall     GetWidth                 (void);

  void        __fastcall     SetHeight                (Word          value);
  Word        __fastcall     GetHeight                (void);

  void        __fastcall     SetMaxWidth              (Word          value);
  Word        __fastcall     GetMaxWidth              (void);

  void        __fastcall     SetMaxHeight             (Word          value);
  Word        __fastcall     GetMaxHeight             (void);

  void        __fastcall     SetSpaceY                (Word          value);
  Word        __fastcall     GetSpaceY                (void);

  void        __fastcall     SetBorderWidth           (Word          value);
  Word        __fastcall     GetBorderWidth           (void);

  void        __fastcall     SetBorderHeight          (Word          value);
  Word        __fastcall     GetBorderHeight          (void);

  void        __fastcall     SetCaption               (AnsiString    value);
  AnsiString  __fastcall     GetCaption               (void);

  void        __fastcall     SetActive                (bool          value);
  bool        __fastcall     GetActive                (void);

  void        __fastcall     FilterButtonOkClick      (TObject      *Sender);
  void        __fastcall     FilterButtonClearClick   (TObject      *Sender);
  void        __fastcall     CheckBoxClick            (TObject      *Sender);

  AnsiString  __fastcall     GetFilter                (void);

  bool                       FilterValueValidByType   (AnsiString   &ValueStr,
                                                       AnsiString   &AddValueStr,
                                                       TFieldType    DataType);

  void                       UpdateFilterValue        (TFieldType    FieldDataType,
                                                       AnsiString    FieldNameStr,
                                                       AnsiString    ValueStr,
                                                       int           OperationTypeCode);

  protected   :
  virtual    void            DataSourceOrderingReversiveSort(AnsiString    FieldNameStr);

  public      :
  __fastcall                 TVCustomDBGridFilterDialog (TComponent* Owner);
  __fastcall virtual        ~TVCustomDBGridFilterDialog (void);

  virtual bool __fastcall    Execute                  (void);
  virtual void __fastcall    ClearFilter              (void);

  __property  AnsiString     Filter        = {read=GetFilter, stored = false};

  __published  :
  __property  TVCustomDBGridFilterFields* Fields = {read=GetFields   , write=SetFields};
  __property  TVDBSortGrid*       Grid          = {read=GetGrid        , write=SetGrid};
  __property  bool           AutoFilter    = {read=GetAutoFilter  , write=SetAutoFilter};
  __property  Word           Width         = {read=GetWidth       , write=SetWidth       , default=0};
  __property  Word           Height        = {read=GetHeight      , write=SetHeight      , default=0};
  __property  Word           MaxWidth      = {read=GetMaxWidth    , write=SetMaxWidth    , default=0};
  __property  Word           MaxHeight     = {read=GetMaxHeight   , write=SetMaxHeight   , default=0};
  __property  Word           SpaceY        = {read=GetSpaceY      , write=SetSpaceY      , default=5};
  __property  Word           BorderWidth   = {read=GetBorderWidth , write=SetBorderWidth , default=5};
  __property  Word           BorderHeight  = {read=GetBorderHeight, write=SetBorderHeight, default=5};
  __property  AnsiString     Caption       = {read=GetCaption     , write=SetCaption};
  __property  bool           Active        = {read=GetActive      , default=false};
 };
//---------------------------------------------------------------------------
#endif
