//---------------------------------------------------------------------------

#ifndef VDBFilterDialogH
#define VDBFilterDialogH
//---------------------------------------------------------------------------
#include <SysUtils.hpp>
#include <Controls.hpp>
#include <Classes.hpp>
#include <Forms.hpp>

#include <dbgrids.hpp>
//---------------------------------------------------------------------------
enum TVDBFilterFieldType
 {
  FieldTypeString    ,
  FieldTypeDigit     ,
  FieldTypeDateTime
 };

class TVDBFilterField : public TCollectionItem
 {
  private:

  AnsiString                           FCaption;
  AnsiString                           FText;
  AnsiString                           FFieldName;
  TVDBFilterFieldType                  FFieldType;
  Word                                 FMaxSize;

  void __fastcall       SetCaption     (AnsiString value);
  AnsiString __fastcall GetCaption     (void);

  void __fastcall       SetText        (AnsiString value);
  AnsiString __fastcall GetText        (void);

  void __fastcall       SetFieldName   (AnsiString value);
  AnsiString __fastcall GetFieldName   (void);

  void __fastcall       SetFieldType   (TVDBFilterFieldType value);
  TVDBFilterFieldType __fastcall
                        GetFieldType   (void);

  void __fastcall       SetMaxSize     (Word value);
  Word __fastcall       GetMaxSize     (void);

  protected:

  virtual AnsiString __fastcall GetDisplayName();

  public:

  __fastcall virtual TVDBFilterField(Classes::TCollection* Collection);
  __fastcall virtual ~TVDBFilterField(void);

  __published:

  __property
    AnsiString          Caption      = {read  = GetCaption,
                                        write = SetCaption};
  __property
    AnsiString          Text         = {read  = GetText,
                                        write = SetText};
  __property
    AnsiString          FieldName    = {read  = GetFieldName,
                                        write = SetFieldName};
  __property
    TVDBFilterFieldType FieldType    = {read  = GetFieldType,
                                        write = SetFieldType};
  __property
    Word                MaxSize      = {read  = GetMaxSize,
                                        write = SetMaxSize};
 };

class TVDBFilterDialog;

class TVDBFilterFields : public TCollection
 {
  private   :

  TVDBFilterDialog       *FilterDialog;
  TVDBFilterField*        GetField(int Index);
  void                    SetField(int Index,TVDBFilterField *Field);

  protected :

  DYNAMIC Classes::TPersistent* __fastcall GetOwner(void);

  public :

  __fastcall TVDBFilterFields(TVDBFilterDialog   *FilterDialog ,
                              System::TMetaClass *FieldClass);
  __fastcall
   virtual  ~TVDBFilterFields(void);

  __property TVDBFilterField* Items[int Index] = {read=GetField, write=SetField};
 };


class PACKAGE TVDBFilterDialog : public TComponent
{
private:
        TVDBFilterFields       *FFields;
        bool                    FAutoFilter;

        void __fastcall              SetFields(TVDBFilterFields* value);
        TVDBFilterFields* __fastcall GetFields();

        void __fastcall  SetAutoFilter(bool Value);
        bool __fastcall  GetAutoFilter();

        TList                         *EditorListPtr;
        TList                         *DateTimePickerListPtr;
        TForm                         *FilterFormPtr;

        AnsiString                     FFilter;
        Word                           FWidth;
        Word                           FHeight;
        Word                           FMaxWidth;
        Word                           FMaxHeight;
        Word                           FSpaceY;
        Word                           FBorderWidth;
        Word                           FBorderHeight;
        AnsiString                     FCaption;
        bool                           FActive;
        AnsiString __fastcall         GetFilter(void);

        void __fastcall FilterButtonOkClick(TObject *Sender);
        void __fastcall SetWidth(Word value);
        Word __fastcall GetWidth();
        void __fastcall SetHeight(Word value);
        Word __fastcall GetHeight();
        void __fastcall SetMaxWidth(Word value);
        Word __fastcall GetMaxWidth();
        void __fastcall SetMaxHeight(Word value);
        Word __fastcall GetMaxHeight();
        void __fastcall SetSpaceY(Word value);
        Word __fastcall GetSpaceY();
        void __fastcall SetBorderWidth(Word value);
        Word __fastcall GetBorderWidth();
        void __fastcall SetBorderHeight(Word value);
        Word __fastcall GetBorderHeight();
        void __fastcall SetCaption(AnsiString value);
        AnsiString __fastcall GetCaption();

        bool            FilterValueValidByType(AnsiString           &ValueStr,
                                               TVDBFilterFieldType   DataType);
        void __fastcall SetActive(bool value);
        bool __fastcall GetActive();

protected:
public:
        __fastcall TVDBFilterDialog(TComponent* Owner);
        __fastcall virtual ~TVDBFilterDialog(void);

        virtual bool __fastcall Execute    (void);

        __property AnsiString Filter = {read=GetFilter , stored = false};

__published:
        __property TVDBFilterFields* Fields  = { read=GetFields, write=SetFields };
        __property bool AutoFilter = { read=GetAutoFilter, write=SetAutoFilter };
        __property Word Width  = { read=GetWidth, write=SetWidth, default = 0 };
        __property Word Height  = { read=GetHeight, write=SetHeight, default=0 };
        __property Word MaxWidth  = { read=GetMaxWidth, write=SetMaxWidth, default=0 };
        __property Word MaxHeight  = { read=GetMaxHeight, write=SetMaxHeight, default=0 };
        __property Word SpaceY  = { read=GetSpaceY, write=SetSpaceY, default=5 };
        __property Word BorderWidth  = { read=GetBorderWidth, write=SetBorderWidth, default=5 };
        __property Word BorderHeight  = { read=GetBorderHeight, write=SetBorderHeight, default=5 };
        __property AnsiString Caption  = { read=GetCaption, write=SetCaption };
        __property bool Active  = { read=GetActive, default=false };
};


//---------------------------------------------------------------------------
#endif
